@@ -15,5 +15,13 @@ options="$common --enable-pthreads $extra"
 #mingw32
 uname | grep MINGW && options="$common --enable-memalign-hack --enable-mingw32 --extra-cflags=-I/usr/local/include --extra-ldflags=-L/usr/local/lib $extra"
 
-svn co svn://svn.mplayerhq.hu/ffmpeg/trunk ffmpeg
+# load FFMPEG specific properties
+. ./ffmpegrev
+
+#Get ffmpeg from svn
+svn -r $FFMPEG_REVISION co $FFMPEG_SVN $FFMPEG_CO_DIR
+sh -c "$FFMPEG_EXTERNALS_UPDATE"
+
+#configure and build ffmpeg
 cd ffmpeg && ./configure $options && make
+
