@@ -1,17 +1,17 @@
 #!/bin/bash
 
-version=0.1.1
+version=0.2.5
 baseurl="http://libkate.googlecode.com/files/libkate-$version.tar.gz"
 
 which wget >& /dev/null
 if [ $? -eq 0 ]
 then
-  wget "$baseurl"
+  test -e "libkate-$version.tar.gz" || wget "$baseurl"
 else
   which curl >& /dev/null
   if [ $? -eq 0 ]
   then
-    curl "$baseurl"
+    test -e "libkate-$version.tar.gz" || curl "$baseurl" -o "libkate-$version.tar.gz"
   else
     echo "Neither wget nor curl were found, cannot download libkate"
     exit 1
@@ -25,6 +25,7 @@ then
 fi
 
 tar xfz "libkate-$version.tar.gz"
+test -L libkate && rm libkate
 ln -fs "libkate-$version" libkate
-cd libkate && make staticlib
+cd libkate && ./configure && make && cd lib
 
